=== modified file 'breezy/builtins.py'
--- breezy/builtins.py	2018-06-04 11:35:48 +0000
+++ breezy/builtins.py	2018-06-14 17:59:16 +0000
@@ -23,6 +23,7 @@
 import sys
 
 import breezy.bzr
+import breezy.git
 
 from . import lazy_import
 lazy_import.lazy_import(globals(), """

=== renamed directory 'breezy/plugins/git' => 'breezy/git'
=== modified file 'breezy/git/__init__.py'
--- breezy/plugins/git/__init__.py	2018-05-13 22:54:28 +0000
+++ breezy/git/__init__.py	2018-06-14 17:59:16 +0000
@@ -31,26 +31,26 @@
 
 from breezy.i18n import gettext
 
-from ... import (
+from .. import (
     __version__ as breezy_version,
     errors as bzr_errors,
     trace,
     version_info,
     )
 
-from ...controldir import (
+from ..controldir import (
     ControlDirFormat,
     Prober,
     format_registry,
     network_format_registry as controldir_network_format_registry,
     )
 
-from ...transport import (
+from ..transport import (
     register_lazy_transport,
     register_transport_proto,
     transport_server_registry,
     )
-from ...commands import (
+from ..commands import (
     plugin_cmds,
     )
 
@@ -93,7 +93,7 @@
     experimental=False,
     )
 
-from ...revisionspec import (RevisionSpec_dwim, revspec_registry)
+from ..revisionspec import (RevisionSpec_dwim, revspec_registry)
 revspec_registry.register_lazy("git:", __name__ + ".revspec",
     "RevisionSpec_git")
 RevisionSpec_dwim.append_possible_lazy_revspec(
@@ -111,7 +111,7 @@
             external_url.startswith("https:")):
             # Already handled by RemoteGitProber
             raise bzr_errors.NotBranchError(path=transport.base)
-        from ... import urlutils
+        from .. import urlutils
         if urlutils.split(transport.base)[1] == ".git":
             raise bzr_errors.NotBranchError(path=transport.base)
         if not transport.has_any(['objects', '.git/objects', '.git']):
@@ -144,10 +144,10 @@
 class RemoteGitProber(Prober):
 
     def probe_http_transport(self, transport):
-        from ... import urlutils
+        from .. import urlutils
         base_url, _ = urlutils.split_segment_parameters(transport.external_url())
         url = urlutils.join(base_url, "info/refs") + "?service=git-upload-pack"
-        from ...transport.http import Request
+        from ..transport.http import Request
         headers = {"Content-Type": "application/x-git-upload-pack-request"}
         req = Request('GET', url, accepted_errors=[200, 403, 404, 405],
                       headers=headers)
@@ -253,7 +253,7 @@
     else:
         stanza.add("git-commit", git_commit)
 
-from ...hooks import install_lazy_named_hook
+from ..hooks import install_lazy_named_hook
 install_lazy_named_hook("breezy.version_info_formats.format_rio",
     "RioVersionInfoBuilder.hooks", "revision", update_stanza,
     "git commits")
@@ -273,7 +273,7 @@
     'serve_git_upload_pack',
     help='Git Smart server upload pack command. (inetd mode only)')
 
-from ...repository import (
+from ..repository import (
     format_registry as repository_format_registry,
     network_format_registry as repository_network_format_registry,
     )
@@ -285,14 +285,14 @@
 register_extra_lazy_repository_format(__name__ + '.repository',
     'GitRepositoryFormat')
 
-from ...branch import (
+from ..branch import (
     network_format_registry as branch_network_format_registry,
     )
 branch_network_format_registry.register_lazy('git',
     __name__ + '.branch', 'LocalGitBranchFormat')
 
 
-from ...branch import (
+from ..branch import (
     format_registry as branch_format_registry,
     )
 branch_format_registry.register_extra_lazy(
@@ -305,7 +305,7 @@
     )
 
 
-from ...workingtree import (
+from ..workingtree import (
     format_registry as workingtree_format_registry,
     )
 workingtree_format_registry.register_extra_lazy(
@@ -318,19 +318,19 @@
 
 
 try:
-    from ...registry import register_lazy
+    from ..registry import register_lazy
 except ImportError:
-    from ...diff import format_registry as diff_format_registry
+    from ..diff import format_registry as diff_format_registry
     diff_format_registry.register_lazy('git', __name__ + '.send',
         'GitDiffTree', 'Git am-style diff format')
 
-    from ...send import (
+    from ..send import (
         format_registry as send_format_registry,
         )
     send_format_registry.register_lazy('git', __name__ + '.send',
                                        'send_git', 'Git am-style diff format')
 
-    from ...directory_service import directories
+    from ..directory_service import directories
     directories.register_lazy('github:', __name__ + '.directory',
                               'GitHubDirectory',
                               'GitHub directory.')
@@ -338,13 +338,13 @@
                               'GitHubDirectory',
                               'GitHub directory.')
 
-    from ...help_topics import (
+    from ..help_topics import (
         topic_registry,
         )
     topic_registry.register_lazy('git', __name__ + '.help', 'help_git',
         'Using Bazaar with Git')
 
-    from ...foreign import (
+    from ..foreign import (
         foreign_vcs_registry,
         )
     foreign_vcs_registry.register_lazy("git",
@@ -427,7 +427,7 @@
     loggerhead_git_hook, "git support")
 
 
-from ...config import (
+from ..config import (
     option_registry,
     Option,
     bool_from_store,

=== modified file 'breezy/git/annotate.py'
--- breezy/plugins/git/annotate.py	2018-03-26 22:28:24 +0000
+++ breezy/git/annotate.py	2018-06-14 17:59:16 +0000
@@ -25,9 +25,9 @@
     tree_lookup_path,
     )
 
-from ...errors import UnavailableRepresentation
-from ...graph import Graph
-from ...revision import (
+from ..errors import UnavailableRepresentation
+from ..graph import Graph
+from ..revision import (
     NULL_REVISION,
     )
 

=== modified file 'breezy/git/branch.py'
--- breezy/plugins/git/branch.py	2018-05-15 19:46:32 +0000
+++ breezy/git/branch.py	2018-06-14 17:59:16 +0000
@@ -28,7 +28,7 @@
     )
 from dulwich.repo import check_ref_format
 
-from ... import (
+from .. import (
     branch,
     config,
     controldir,
@@ -41,10 +41,10 @@
     transport,
     urlutils,
     )
-from ...revision import (
+from ..revision import (
     NULL_REVISION,
     )
-from ...trace import (
+from ..trace import (
     is_quiet,
     mutter,
     warning,
@@ -74,7 +74,7 @@
     )
 from .urls import git_url_to_bzr_url
 
-from ...foreign import ForeignBranch
+from ..foreign import ForeignBranch
 
 
 class GitPullResult(branch.PullResult):

=== modified file 'breezy/git/cache.py'
--- breezy/plugins/git/cache.py	2018-05-13 22:54:28 +0000
+++ breezy/git/cache.py	2018-06-14 17:59:16 +0000
@@ -29,18 +29,18 @@
     ShaFile,
     )
 
-from ... import (
+from .. import (
     errors as bzr_errors,
     osutils,
     registry,
     trace,
     )
-from ...bzr import (
+from ..bzr import (
     btree_index as _mod_btree_index,
     index as _mod_index,
     versionedfile,
     )
-from ...transport import (
+from ..transport import (
     get_transport,
     )
 
@@ -49,7 +49,7 @@
     try:
         from xdg.BaseDirectory import xdg_cache_home
     except ImportError:
-        from ...config import config_dir
+        from ..config import config_dir
         ret = os.path.join(config_dir(), "git")
     else:
         ret = os.path.join(xdg_cache_home, "breezy", "git")
@@ -219,7 +219,7 @@
         :param repository: Repository to open the cache for
         :return: A `BzrGitCache`
         """
-        from ...transport.local import LocalTransport
+        from ..transport.local import LocalTransport
         repo_transport = getattr(repository, "_transport", None)
         if (repo_transport is not None and
             isinstance(repo_transport, LocalTransport)):
@@ -813,7 +813,7 @@
             except bzr_errors.FileExists:
                 pass
             return cls(transport.clone('git'))
-        from ...transport import get_transport
+        from ..transport import get_transport
         return cls(get_transport(get_cache_dir()))
 
     def __repr__(self):

=== modified file 'breezy/git/commands.py'
--- breezy/plugins/git/commands.py	2018-05-15 01:15:56 +0000
+++ breezy/git/commands.py	2018-06-14 17:59:16 +0000
@@ -24,14 +24,14 @@
 from __future__ import absolute_import
 
 import breezy.bzr.bzrdir
-from ...commands import (
+from ..commands import (
     Command,
     display_command,
     )
-from ...option import (
+from ..option import (
     Option,
     )
-from ...sixish import (
+from ..sixish import (
     text_type,
     )
 
@@ -48,15 +48,15 @@
                      ]
 
     def _get_colocated_branch(self, target_controldir, name):
-        from ...errors import NotBranchError
+        from ..errors import NotBranchError
         try:
             return target_controldir.open_branch(name=name)
         except NotBranchError:
             return target_controldir.create_branch(name=name)
 
     def _get_nested_branch(self, dest_transport, dest_format, name):
-        from ...controldir import ControlDir
-        from ...errors import NotBranchError
+        from ..controldir import ControlDir
+        from ..errors import NotBranchError
         head_transport = dest_transport.clone(name)
         try:
             head_controldir = ControlDir.open_from_transport(head_transport)
@@ -71,26 +71,26 @@
     def run(self, src_location, dest_location=None, colocated=False):
         import os
         import urllib
-        from ... import (
+        from .. import (
             controldir,
             trace,
             ui,
             urlutils,
             )
-        from ...controldir import (
+        from ..controldir import (
             ControlDir,
             )
-        from ...errors import (
+        from ..errors import (
             BzrCommandError,
             NoRepositoryPresent,
             NotBranchError,
             )
         from . import gettext
-        from ...repository import (
+        from ..repository import (
             InterRepository,
             Repository,
             )
-        from ...transport import get_transport
+        from ..transport import get_transport
         from .branch import (
             LocalGitBranch,
             )
@@ -178,10 +178,10 @@
 
     @display_command
     def run(self, sha1=None, directory=".", pretty=False):
-        from ...errors import (
+        from ..errors import (
             BzrCommandError,
             )
-        from ...controldir import (
+        from ..controldir import (
             ControlDir,
             )
         from .object_store import (
@@ -218,7 +218,7 @@
 
     @display_command
     def run(self, location="."):
-        from ...controldir import (
+        from ..controldir import (
             ControlDir,
             )
         from .refs import (
@@ -258,7 +258,7 @@
         :param signoff: Add Signed-Off-By flag.
         """
         from . import gettext
-        from ...errors import BzrCommandError
+        from ..errors import BzrCommandError
         from dulwich.patch import git_am_patch_split
         import subprocess
         (c, diff, version) = git_am_patch_split(f)
@@ -277,8 +277,8 @@
         wt.commit(authors=[c.author], message=message)
 
     def run(self, patches_list=None, signoff=False, force=False):
-        from ...errors import UncommittedChanges
-        from ...workingtree import WorkingTree
+        from ..errors import UncommittedChanges
+        from ..workingtree import WorkingTree
         if patches_list is None:
             patches_list = []
 
@@ -300,13 +300,13 @@
     takes_args = ['target', 'package']
 
     def run(self, target, package, directory='.'):
-        from ...branch import Branch
-        from ...errors import (
+        from ..branch import Branch
+        from ..errors import (
             BzrCommandError,
             NoSuchRevision,
             )
-        from ...trace import warning
-        from ...repository import Repository
+        from ..trace import warning
+        from ..repository import Repository
         from .object_store import get_object_store
         from .pristine_tar import (
             revision_pristine_tar_data,

=== modified file 'breezy/git/commit.py'
--- breezy/plugins/git/commit.py	2018-05-13 22:54:28 +0000
+++ breezy/git/commit.py	2018-06-14 17:59:16 +0000
@@ -25,18 +25,18 @@
 import os
 import stat
 
-from ... import (
+from .. import (
     config as _mod_config,
     gpg,
     osutils,
     revision as _mod_revision,
     )
-from ...errors import (
+from ..errors import (
     BzrError,
     RootMissing,
     UnsupportedOperation,
     )
-from ...repository import (
+from ..repository import (
     CommitBuilder,
     )
 

=== modified file 'breezy/git/config.py'
--- breezy/plugins/git/config.py	2018-03-26 22:28:24 +0000
+++ breezy/git/config.py	2018-06-14 17:59:16 +0000
@@ -18,7 +18,7 @@
 
 from __future__ import absolute_import
 
-from ... import (
+from .. import (
     config,
     )
 

=== modified file 'breezy/git/dir.py'
--- breezy/plugins/git/dir.py	2018-05-13 22:54:28 +0000
+++ breezy/git/dir.py	2018-06-14 17:59:16 +0000
@@ -21,7 +21,7 @@
 
 import urllib
 
-from ... import (
+from .. import (
     branch as _mod_branch,
     errors as bzr_errors,
     trace,
@@ -30,12 +30,12 @@
     revision as _mod_revision,
     urlutils,
     )
-from ...transport import (
+from ..transport import (
     do_catching_redirections,
     get_transport_from_path,
     )
 
-from ...controldir import (
+from ..controldir import (
     BranchReferenceLoop,
     ControlDir,
     ControlDirFormat,
@@ -153,9 +153,9 @@
                recurse='down', possible_transports=None,
                accelerator_tree=None, hardlink=False, stacked=False,
                source_branch=None, create_tree_if_local=True):
-        from ...repository import InterRepository
-        from ...transport.local import LocalTransport
-        from ...transport import get_transport
+        from ..repository import InterRepository
+        from ..transport.local import LocalTransport
+        from ..transport import get_transport
         target_transport = get_transport(url, possible_transports)
         target_transport.ensure_base()
         cloning_format = self.cloning_metadir()
@@ -197,7 +197,7 @@
         force_new_repo=False, preserve_stacking=False, stacked_on=None,
         create_prefix=False, use_existing_dir=True, no_tree=False):
         """See ControlDir.clone_on_transport."""
-        from ...repository import InterRepository
+        from ..repository import InterRepository
         from .mapping import default_mapping
         if stacked_on is not None:
             raise _mod_branch.UnstackableBranchFormat(self._format, self.user_url)

=== modified file 'breezy/git/directory.py'
--- breezy/plugins/git/directory.py	2018-03-26 22:28:24 +0000
+++ breezy/git/directory.py	2018-06-14 17:59:16 +0000
@@ -19,7 +19,7 @@
 
 from __future__ import absolute_import
 
-from ... import transport
+from .. import transport
 
 transport.register_urlparse_netloc_protocol('github')
 

=== modified file 'breezy/git/errors.py'
--- breezy/plugins/git/errors.py	2018-03-26 22:28:24 +0000
+++ breezy/git/errors.py	2018-06-14 17:59:16 +0000
@@ -22,7 +22,7 @@
 
 from dulwich import errors as git_errors
 
-from ... import errors as bzr_errors
+from .. import errors as bzr_errors
 
 
 class BzrGitError(bzr_errors.BzrError):

=== modified file 'breezy/git/fetch.py'
--- breezy/plugins/git/fetch.py	2018-05-13 22:54:28 +0000
+++ breezy/git/fetch.py	2018-06-14 17:59:16 +0000
@@ -33,36 +33,36 @@
 import posixpath
 import stat
 
-from ... import (
+from .. import (
     debug,
     errors,
     osutils,
     trace,
     ui,
     )
-from ...errors import (
+from ..errors import (
     BzrError,
     )
-from ...bzr.inventory import (
+from ..bzr.inventory import (
     InventoryDirectory,
     InventoryFile,
     InventoryLink,
     TreeReference,
     )
-from ...repository import (
+from ..repository import (
     InterRepository,
     )
-from ...revision import (
+from ..revision import (
     NULL_REVISION,
     )
-from ...bzr.inventorytree import InventoryRevisionTree
-from ...testament import (
+from ..bzr.inventorytree import InventoryRevisionTree
+from ..testament import (
     StrictTestament3,
     )
-from ...tsort import (
+from ..tsort import (
     topo_sort,
     )
-from ...bzr.versionedfile import (
+from ..bzr.versionedfile import (
     ChunkedContentFactory,
     )
 

=== modified file 'breezy/git/filegraph.py'
--- breezy/plugins/git/filegraph.py	2018-03-26 22:28:24 +0000
+++ breezy/git/filegraph.py	2018-06-14 17:59:16 +0000
@@ -28,7 +28,7 @@
     tree_lookup_path,
     )
 
-from ...revision import (
+from ..revision import (
     NULL_REVISION,
     )
 

=== modified file 'breezy/git/git_remote_helper.py'
--- breezy/plugins/git/git_remote_helper.py	2018-03-26 22:28:24 +0000
+++ breezy/git/git_remote_helper.py	2018-06-14 17:59:16 +0000
@@ -26,10 +26,10 @@
 
 import os
 
-from ...controldir import ControlDir
-from ...errors import NotBranchError, NoRepositoryPresent
-from ...repository import InterRepository
-from ...transport import get_transport_from_path
+from ..controldir import ControlDir
+from ..errors import NotBranchError, NoRepositoryPresent
+from ..repository import InterRepository
+from ..transport import get_transport_from_path
 
 from . import (
     LocalGitProber,
@@ -50,7 +50,7 @@
     GitRepository,
     )
 
-from ..fastimport import exporter as fastexporter
+from ..plugins.fastimport import exporter as fastexporter
 
 try:
     import fastimport

=== modified file 'breezy/git/interrepo.py'
--- breezy/plugins/git/interrepo.py	2018-04-07 17:26:07 +0000
+++ breezy/git/interrepo.py	2018-06-14 17:59:16 +0000
@@ -32,7 +32,7 @@
     )
 from dulwich.walk import Walker
 
-from ...errors import (
+from ..errors import (
     DivergedBranches,
     FetchLimitUnsupported,
     InvalidRevisionId,
@@ -40,13 +40,13 @@
     NoRoundtrippingSupport,
     NoSuchRevision,
     )
-from ...repository import (
+from ..repository import (
     InterRepository,
     )
-from ...revision import (
+from ..revision import (
     NULL_REVISION,
     )
-from ... import (
+from .. import (
     config,
     trace,
     ui,

=== modified file 'breezy/git/mapping.py'
--- breezy/plugins/git/mapping.py	2018-05-15 01:20:00 +0000
+++ breezy/git/mapping.py	2018-06-14 17:59:16 +0000
@@ -23,21 +23,21 @@
 import base64
 import stat
 
-from ... import (
+from .. import (
     bencode,
     errors,
     foreign,
     trace,
     )
-from ...bzr.inventory import (
+from ..bzr.inventory import (
     ROOT_ID,
     )
-from ...foreign import (
+from ..foreign import (
     ForeignVcs,
     VcsMappingRegistry,
     ForeignRevision,
     )
-from ...revision import (
+from ..revision import (
     NULL_REVISION,
     )
 from .errors import (
@@ -507,10 +507,10 @@
 
 
 mapping_registry = GitMappingRegistry()
-mapping_registry.register_lazy('git-v1', "breezy.plugins.git.mapping",
+mapping_registry.register_lazy('git-v1', __name__,
     "BzrGitMappingv1")
 mapping_registry.register_lazy('git-experimental',
-    "breezy.plugins.git.mapping", "BzrGitMappingExperimental")
+    __name__, "BzrGitMappingExperimental")
 # Uncomment the next line to enable the experimental bzr-git mappings.
 # This will make sure all bzr metadata is pushed into git, allowing for
 # full roundtripping later.

=== modified file 'breezy/git/object_store.py'
--- breezy/plugins/git/object_store.py	2018-05-13 22:54:28 +0000
+++ breezy/git/object_store.py	2018-06-14 17:59:16 +0000
@@ -35,7 +35,7 @@
     Pack,
     )
 
-from ... import (
+from .. import (
     errors,
     lru_cache,
     trace,
@@ -43,11 +43,11 @@
     ui,
     urlutils,
     )
-from ...lock import LogicalLockResult
-from ...revision import (
+from ..lock import LogicalLockResult
+from ..revision import (
     NULL_REVISION,
     )
-from ...testament import(
+from ..testament import(
     StrictTestament3,
     )
 

=== modified file 'breezy/git/push.py'
--- breezy/plugins/git/push.py	2018-04-07 17:26:07 +0000
+++ breezy/git/push.py	2018-06-14 17:59:16 +0000
@@ -18,7 +18,7 @@
 
 from __future__ import absolute_import
 
-from ...push import (
+from ..push import (
     PushResult,
     )
 from .errors import (

=== modified file 'breezy/git/refs.py'
--- breezy/plugins/git/refs.py	2018-05-13 22:54:28 +0000
+++ breezy/git/refs.py	2018-06-14 17:59:16 +0000
@@ -27,7 +27,7 @@
     RefsContainer,
     )
 
-from ... import (
+from .. import (
     errors,
     osutils,
     revision as _mod_revision,

=== modified file 'breezy/git/remote.py'
--- breezy/plugins/git/remote.py	2018-05-20 16:08:36 +0000
+++ breezy/git/remote.py	2018-06-14 17:59:16 +0000
@@ -21,7 +21,7 @@
 from io import BytesIO
 import re
 
-from ... import (
+from .. import (
     config,
     debug,
     errors,
@@ -30,10 +30,10 @@
     ui,
     urlutils,
     )
-from ...push import (
+from ..push import (
     PushResult,
     )
-from ...errors import (
+from ..errors import (
     AlreadyBranchError,
     BzrError,
     DivergedBranches,
@@ -47,8 +47,8 @@
     NoWorkingTree,
     UninitializableFormat,
     )
-from ...revisiontree import RevisionTree
-from ...transport import (
+from ..revisiontree import RevisionTree
+from ..transport import (
     Transport,
     register_urlparse_netloc_protocol,
     )
@@ -266,7 +266,7 @@
 class DulwichSSHVendor(dulwich.client.SSHVendor):
 
     def __init__(self):
-        from ...transport import ssh
+        from ..transport import ssh
         self.bzr_ssh_vendor = ssh._get_ssh_vendor()
 
     def run_command(self, host, command, username=None, port=None):

=== modified file 'breezy/git/repository.py'
--- breezy/plugins/git/repository.py	2018-05-14 20:32:14 +0000
+++ breezy/git/repository.py	2018-06-14 17:59:16 +0000
@@ -19,7 +19,7 @@
 
 from __future__ import absolute_import
 
-from ... import (
+from .. import (
     check,
     errors,
     graph as _mod_graph,
@@ -31,8 +31,8 @@
     ui,
     version_info as breezy_version,
     )
-from ...decorators import only_raises
-from ...foreign import (
+from ..decorators import only_raises
+from ..foreign import (
     ForeignRepository,
     )
 

=== modified file 'breezy/git/revspec.py'
--- breezy/plugins/git/revspec.py	2018-05-13 22:54:28 +0000
+++ breezy/git/revspec.py	2018-06-14 17:59:16 +0000
@@ -21,15 +21,15 @@
 # Please note that imports are delayed as much as possible here since
 # if DWIM revspecs are supported this module is imported by __init__.py.
 
-from ... import version_info as breezy_version
-from ...errors import (
+from .. import version_info as breezy_version
+from ..errors import (
     InvalidRevisionId,
     InvalidRevisionSpec,
     )
-from ...revision import (
+from ..revision import (
     NULL_REVISION,
 )
-from ...revisionspec import (
+from ..revisionspec import (
     RevisionInfo,
     RevisionSpec,
     )

=== modified file 'breezy/git/roundtrip.py'
--- breezy/plugins/git/roundtrip.py	2018-05-14 20:02:30 +0000
+++ breezy/git/roundtrip.py	2018-06-14 17:59:16 +0000
@@ -47,7 +47,7 @@
 
 from __future__ import absolute_import
 
-from ... import osutils
+from .. import osutils
 
 from io import BytesIO
 

=== modified file 'breezy/git/send.py'
--- breezy/plugins/git/send.py	2018-05-13 22:54:28 +0000
+++ breezy/git/send.py	2018-06-14 17:59:16 +0000
@@ -23,8 +23,8 @@
 from __future__ import absolute_import
 
 import time
-from ... import __version__ as bzr_version
-from ... import (
+from .. import __version__ as bzr_version
+from .. import (
     branch as _mod_branch,
     diff as _mod_diff,
     errors,
@@ -32,7 +32,7 @@
     revision as _mod_revision,
     )
 
-from ...merge_directive import BaseMergeDirective
+from ..merge_directive import BaseMergeDirective
 
 from . import (
     version_info as bzr_git_version_info,

=== modified file 'breezy/git/server.py'
--- breezy/plugins/git/server.py	2018-03-26 22:28:24 +0000
+++ breezy/git/server.py	2018-06-14 17:59:16 +0000
@@ -22,12 +22,12 @@
 
 import sys
 
-from ... import (
+from .. import (
     errors,
     trace,
     )
 
-from ...controldir import (
+from ..controldir import (
     ControlDir,
     )
 

=== modified file 'breezy/git/tests/__init__.py'
--- breezy/plugins/git/tests/__init__.py	2018-05-15 18:31:59 +0000
+++ breezy/git/tests/__init__.py	2018-06-14 17:59:16 +0000
@@ -23,11 +23,11 @@
 
 import time
 
-from .... import (
+from ... import (
     errors as bzr_errors,
     tests,
     )
-from ....tests.features import (
+from ...tests.features import (
     Feature,
     ModuleAvailableFeature,
     )

=== modified file 'breezy/git/tests/test_blackbox.py'
--- breezy/plugins/git/tests/test_blackbox.py	2018-05-15 19:46:32 +0000
+++ breezy/git/tests/test_blackbox.py	2018-06-14 17:59:16 +0000
@@ -25,14 +25,14 @@
 
 import os
 
-from .... import (
+from ... import (
     version_info as breezy_version,
     )
-from ....controldir import (
+from ...controldir import (
     ControlDir,
     )
 
-from ....tests.blackbox import ExternalBase
+from ...tests.blackbox import ExternalBase
 
 from .. import (
     tests,

=== modified file 'breezy/git/tests/test_branch.py'
--- breezy/plugins/git/tests/test_branch.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_branch.py	2018-06-14 17:59:16 +0000
@@ -32,20 +32,20 @@
 import os
 import urllib
 
-from .... import (
+from ... import (
     errors,
     revision,
     urlutils,
     )
-from ....branch import (
+from ...branch import (
     Branch,
     InterBranch,
     UnstackableBranchFormat,
     )
-from ....controldir import (
+from ...controldir import (
     ControlDir,
     )
-from ....repository import (
+from ...repository import (
     Repository,
     )
 

=== modified file 'breezy/git/tests/test_cache.py'
--- breezy/plugins/git/tests/test_cache.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_cache.py	2018-06-14 17:59:16 +0000
@@ -27,24 +27,24 @@
 import os
 import stat
 
-from .... import osutils
+from ... import osutils
 
-from ....bzr.inventory import (
+from ...bzr.inventory import (
     InventoryFile,
     InventoryDirectory,
     ROOT_ID,
     )
 
-from ....revision import (
+from ...revision import (
     Revision,
     )
 
-from ....tests import (
+from ...tests import (
     TestCase,
     TestCaseInTempDir,
     UnavailableFeature,
     )
-from ....transport import (
+from ...transport import (
     get_transport,
     )
 

=== modified file 'breezy/git/tests/test_dir.py'
--- breezy/plugins/git/tests/test_dir.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_dir.py	2018-06-14 17:59:16 +0000
@@ -22,12 +22,12 @@
 from dulwich.repo import Repo as GitRepo
 import os
 
-from .... import (
+from ... import (
     controldir,
     errors,
     urlutils,
     )
-from ....tests import TestSkipped
+from ...tests import TestSkipped
 
 from .. import (
     dir,

=== modified file 'breezy/git/tests/test_fetch.py'
--- breezy/plugins/git/tests/test_fetch.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_fetch.py	2018-06-14 17:59:16 +0000
@@ -32,26 +32,26 @@
 import stat
 import time
 
-from .... import (
+from ... import (
     osutils,
     )
-from ....bzr import (
+from ...bzr import (
     knit,
     versionedfile,
     )
-from ....branch import (
+from ...branch import (
     Branch,
     )
-from ....controldir import (
+from ...controldir import (
     ControlDir,
     )
-from ....bzr.inventory import (
+from ...bzr.inventory import (
     Inventory,
     )
-from ....repository import (
+from ...repository import (
     Repository,
     )
-from ....tests import (
+from ...tests import (
     TestCaseWithTransport,
     )
 

=== modified file 'breezy/git/tests/test_git_remote_helper.py'
--- breezy/plugins/git/tests/test_git_remote_helper.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_git_remote_helper.py	2018-06-14 17:59:16 +0000
@@ -26,7 +26,7 @@
 
 from dulwich.repo import Repo
 
-from ....tests import (
+from ...tests import (
     TestCaseWithTransport,
     TestSkipped,
     )

=== modified file 'breezy/git/tests/test_mapping.py'
--- breezy/plugins/git/tests/test_mapping.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_mapping.py	2018-06-14 17:59:16 +0000
@@ -19,7 +19,7 @@
 
 from __future__ import absolute_import
 
-from ....revision import (
+from ...revision import (
     Revision,
     )
 

=== modified file 'breezy/git/tests/test_memorytree.py'
--- breezy/plugins/git/tests/test_memorytree.py	2018-05-13 22:54:28 +0000
+++ breezy/git/tests/test_memorytree.py	2018-06-14 17:59:16 +0000
@@ -17,8 +17,8 @@
 
 """Tests for the GitMemoryTree class."""
 
-from .... import errors
-from ....treebuilder import TreeBuilder
+from ... import errors
+from ...treebuilder import TreeBuilder
 from . import TestCaseWithTransport
 
 

=== modified file 'breezy/git/tests/test_object_store.py'
--- breezy/plugins/git/tests/test_object_store.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_object_store.py	2018-06-14 17:59:16 +0000
@@ -23,21 +23,21 @@
     Tree,
     )
 
-from ....branchbuilder import (
+from ...branchbuilder import (
     BranchBuilder,
     )
-from ....bzr.inventory import (
+from ...bzr.inventory import (
     InventoryDirectory,
     InventoryFile,
     )
-from ....errors import (
+from ...errors import (
     NoSuchRevision,
     )
-from ....graph import (
+from ...graph import (
     DictParentsProvider,
     Graph,
     )
-from ....tests import (
+from ...tests import (
     TestCase,
     TestCaseWithTransport,
     )

=== modified file 'breezy/git/tests/test_pristine_tar.py'
--- breezy/plugins/git/tests/test_pristine_tar.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_pristine_tar.py	2018-06-14 17:59:16 +0000
@@ -27,8 +27,8 @@
     store_git_pristine_tar_data,
     )
 
-from ....revision import Revision
-from ....tests import TestCase
+from ...revision import Revision
+from ...tests import TestCase
 
 from dulwich.objects import (
     Blob,

=== modified file 'breezy/git/tests/test_push.py'
--- breezy/plugins/git/tests/test_push.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_push.py	2018-06-14 17:59:16 +0000
@@ -19,13 +19,13 @@
 
 from __future__ import absolute_import
 
-from ....controldir import (
+from ...controldir import (
     format_registry,
     )
-from ....repository import (
+from ...repository import (
     InterRepository,
     )
-from ....tests import (
+from ...tests import (
     TestCaseWithTransport,
     )
 

=== modified file 'breezy/git/tests/test_refs.py'
--- breezy/plugins/git/tests/test_refs.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_refs.py	2018-06-14 17:59:16 +0000
@@ -20,7 +20,7 @@
 
 from __future__ import absolute_import
 
-from .... import tests
+from ... import tests
 
 from ..object_store import BazaarObjectStore
 from ..refs import (

=== modified file 'breezy/git/tests/test_remote.py'
--- breezy/plugins/git/tests/test_remote.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_remote.py	2018-06-14 17:59:16 +0000
@@ -23,19 +23,19 @@
 import os
 import time
 
-from ....controldir import ControlDir
-from ....errors import (
+from ...controldir import ControlDir
+from ...errors import (
     BzrError,
     DivergedBranches,
     NotBranchError,
     NoSuchTag,
     )
 
-from ....tests import (
+from ...tests import (
     TestCase,
     TestCaseWithTransport,
     )
-from ....tests.features import ExecutableFeature
+from ...tests.features import ExecutableFeature
 
 from ..mapping import default_mapping
 from ..remote import (

=== modified file 'breezy/git/tests/test_repository.py'
--- breezy/plugins/git/tests/test_repository.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_repository.py	2018-06-14 17:59:16 +0000
@@ -25,12 +25,12 @@
     )
 import os
 
-from .... import (
+from ... import (
     config,
     errors,
     revision,
     )
-from ....repository import (
+from ...repository import (
     InterRepository,
     Repository,
     )

=== modified file 'breezy/git/tests/test_revspec.py'
--- breezy/plugins/git/tests/test_revspec.py	2018-05-13 22:54:28 +0000
+++ breezy/git/tests/test_revspec.py	2018-06-14 17:59:16 +0000
@@ -18,7 +18,7 @@
 
 from __future__ import absolute_import
 
-from ....tests import TestCase
+from ...tests import TestCase
 
 from ..revspec import (
     valid_git_sha1,

=== modified file 'breezy/git/tests/test_roundtrip.py'
--- breezy/plugins/git/tests/test_roundtrip.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_roundtrip.py	2018-06-14 17:59:16 +0000
@@ -20,7 +20,7 @@
 
 from __future__ import absolute_import
 
-from ....tests import TestCase
+from ...tests import TestCase
 
 from ..roundtrip import (
     CommitSupplement,

=== modified file 'breezy/git/tests/test_server.py'
--- breezy/plugins/git/tests/test_server.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_server.py	2018-06-14 17:59:16 +0000
@@ -22,8 +22,8 @@
 from dulwich.repo import Repo
 import threading
 
-from ....transport import transport_server_registry
-from ....tests import (
+from ...transport import transport_server_registry
+from ...tests import (
     TestCase,
     TestCaseWithTransport,
     )

=== modified file 'breezy/git/tests/test_transportgit.py'
--- breezy/plugins/git/tests/test_transportgit.py	2018-05-13 22:54:28 +0000
+++ breezy/git/tests/test_transportgit.py	2018-06-14 17:59:16 +0000
@@ -22,7 +22,7 @@
 from dulwich.tests.test_object_store import PackBasedObjectStoreTests
 from dulwich.tests.utils import make_object
 
-from ....tests import TestCaseWithTransport
+from ...tests import TestCaseWithTransport
 
 from ..transportgit import TransportObjectStore
 

=== modified file 'breezy/git/tests/test_unpeel_map.py'
--- breezy/plugins/git/tests/test_unpeel_map.py	2018-05-14 20:02:30 +0000
+++ breezy/git/tests/test_unpeel_map.py	2018-06-14 17:59:16 +0000
@@ -20,7 +20,7 @@
 
 from io import BytesIO
 
-from ....tests import (
+from ...tests import (
     TestCaseWithTransport,
     )
 

=== modified file 'breezy/git/tests/test_urls.py'
--- breezy/plugins/git/tests/test_urls.py	2018-04-02 14:42:37 +0000
+++ breezy/git/tests/test_urls.py	2018-06-14 17:59:16 +0000
@@ -18,7 +18,7 @@
 
 from __future__ import absolute_import
 
-from ....tests import TestCase
+from ...tests import TestCase
 from ..urls import (
     git_url_to_bzr_url,
     )

=== modified file 'breezy/git/tests/test_workingtree.py'
--- breezy/plugins/git/tests/test_workingtree.py	2018-06-07 17:12:34 +0000
+++ breezy/git/tests/test_workingtree.py	2018-06-14 17:59:16 +0000
@@ -28,10 +28,10 @@
     ZERO_SHA,
     )
 
-from .... import (
+from ... import (
     conflicts as _mod_conflicts,
     )
-from ....delta import TreeDelta
+from ...delta import TreeDelta
 from ..mapping import (
     default_mapping,
     GitFileIdMap,
@@ -43,7 +43,7 @@
 from ..workingtree import (
     FLAG_STAGEMASK,
     )
-from ....tests import (
+from ...tests import (
     TestCase,
     TestCaseWithTransport,
     )

=== modified file 'breezy/git/transportgit.py'
--- breezy/plugins/git/transportgit.py	2018-05-13 22:54:28 +0000
+++ breezy/git/transportgit.py	2018-06-14 17:59:16 +0000
@@ -66,10 +66,10 @@
     write_packed_refs,
     )
 
-from ... import (
+from .. import (
     transport as _mod_transport,
     )
-from ...errors import (
+from ..errors import (
     AlreadyControlDirError,
     FileExists,
     LockBroken,
@@ -81,7 +81,7 @@
     TransportNotPossible,
     )
 
-from ...lock import LogicalLockResult
+from ..lock import LogicalLockResult
 
 
 class TransportRefsContainer(RefsContainer):

=== modified file 'breezy/git/tree.py'
--- breezy/plugins/git/tree.py	2018-06-07 17:12:34 +0000
+++ breezy/git/tree.py	2018-06-14 17:59:16 +0000
@@ -43,7 +43,7 @@
 import stat
 import posixpath
 
-from ... import (
+from .. import (
     controldir as _mod_controldir,
     delta,
     errors,
@@ -55,7 +55,7 @@
     tree as _mod_tree,
     workingtree,
     )
-from ...revision import (
+from ..revision import (
     CURRENT_REVISION,
     NULL_REVISION,
     )

=== modified file 'breezy/git/unpeel_map.py'
--- breezy/plugins/git/unpeel_map.py	2018-05-13 22:54:28 +0000
+++ breezy/git/unpeel_map.py	2018-06-14 17:59:16 +0000
@@ -21,7 +21,7 @@
 from collections import defaultdict
 from io import BytesIO
 
-from ... import (
+from .. import (
     errors,
     trace,
     )

=== modified file 'breezy/git/workingtree.py'
--- breezy/plugins/git/workingtree.py	2018-06-07 16:55:46 +0000
+++ breezy/git/workingtree.py	2018-06-14 17:59:16 +0000
@@ -59,7 +59,7 @@
 import stat
 import sys
 
-from ... import (
+from .. import (
     conflicts as _mod_conflicts,
     errors,
     controldir as _mod_controldir,
@@ -74,13 +74,13 @@
     tree,
     workingtree,
     )
-from ...decorators import (
+from ..decorators import (
     only_raises,
     )
-from ...bzr import (
+from ..bzr import (
     inventory,
     )
-from ...mutabletree import (
+from ..mutabletree import (
     BadReferenceTarget,
     MutableTree,
     )

=== modified file 'breezy/tests/__init__.py'
--- breezy/tests/__init__.py	2018-05-11 00:02:31 +0000
+++ breezy/tests/__init__.py	2018-06-14 17:59:16 +0000
@@ -3861,6 +3861,28 @@
     """Return the standard list of test module names to test."""
     return [
         'breezy.doc',
+        'breezy.git.tests.test_blackbox',
+        'breezy.git.tests.test_builder',
+        'breezy.git.tests.test_branch',
+        'breezy.git.tests.test_cache',
+        'breezy.git.tests.test_dir',
+        'breezy.git.tests.test_fetch',
+        'breezy.git.tests.test_git_remote_helper',
+        'breezy.git.tests.test_mapping',
+        'breezy.git.tests.test_memorytree',
+        'breezy.git.tests.test_object_store',
+        'breezy.git.tests.test_pristine_tar',
+        'breezy.git.tests.test_push',
+        'breezy.git.tests.test_remote',
+        'breezy.git.tests.test_repository',
+        'breezy.git.tests.test_refs',
+        'breezy.git.tests.test_revspec',
+        'breezy.git.tests.test_roundtrip',
+        'breezy.git.tests.test_server',
+        'breezy.git.tests.test_transportgit',
+        'breezy.git.tests.test_unpeel_map',
+        'breezy.git.tests.test_urls',
+        'breezy.git.tests.test_workingtree',
         'breezy.tests.blackbox',
         'breezy.tests.commands',
         'breezy.tests.per_branch',

